@@ -7,10 +7,14 @@ class RawCodexMode(BaseMode):
   title = 'Codex'
 
   def __init__(self, state={}):
-    self.llm = GPT3(model='code-davinci-002', temperature=0.1)
+    self.llm = GPT3()
 
   def ask(self, text):
     yield '```\n'
-    for data in self.llm.complete(text, stream=True):
+    for data in self.llm.complete(
+        text, stream=True,
+        model='code-davinci-002',
+        temperature=0.1,
+    ):
       yield data
     yield '\n```'
