@@ -1,4 +1,4 @@
-from .misc import peek
+from .misc import peek, clear_screen, copy_to_clipboard
 from .printer import printer
 from .loader import Loader
 from .editor import open_in_editor
